package com.mdtexfx.processors;

/**
 * Responsible for creating processors that can transform source documents
 * into output documents.
 */
public class ProcessorFactory {

  /**
   * Creates a new {@link Processor} chain capable of transforming documents.
   *
   * @param context Contains information required to instantiate various
   *                {@link Processor} types.
   * @return A complete {@link Processor} chain capable of transforming
   * an input document to the desired output format.
   */
  public static Processor<String> create( final ProcessorContext context ) {
    final var successor = new HtmlProcessor( context );

    final var processor = switch( context.getMediaType() ) {
      case UNDEFINED -> new IdentityProcessor( successor, context );
      case TEXT_MARKDOWN -> new MarkdownProcessor( successor, context );
    };

    return new ExecutorProcessor<>( processor );
  }
}
